==> blesta-3.1.1.zip: blesta/plugins/support_manager/language/en_us/client_tickets.php <==
<?php
// Success Messages
$lang['ClientTickets.!success.ticket_created'] = "The ticket #%1\$s has been successfully created."; // %1$s is the ticket number
$lang['ClientTickets.!success.ticket_updated'] = "The ticket #%1\$s has been successfully updated."; // %1$s is the ticket number
$lang['ClientTickets.!success.ticket_closed'] = "The ticket #%1\$s has been successfully closed."; // %1$s is the ticket number


// Notice messages
$lang['ClientTickets.!notice.no_departments'] = "There are no support departments available.";


// Page Titles
$lang['ClientTickets.index.page_title'] = "Support > Tickets";
$lang['ClientTickets.add.page_title'] = "Support > Open Ticket";
$lang['ClientTickets.reply.page_title'] = "Support > Update Ticket";


// Index
$lang['ClientTickets.index.category_open'] = "Open";
$lang['ClientTickets.index.category_closed'] = "Closed";

$lang['ClientTickets.index.categorylink_createticket'] = "Open Ticket";

$lang['ClientTickets.index.boxtitle_tickets'] = "Tickets";

$lang['ClientTickets.index.heading_code'] = "Ticket Number";
$lang['ClientTickets.index.heading_priority'] = "Priority";
$lang['ClientTickets.index.heading_department_name'] = "Department";
$lang['ClientTickets.index.heading_summary'] = "Summary";
$lang['ClientTickets.index.heading_last_reply_date'] = "Last Reply";
$lang['ClientTickets.index.heading_status'] = "Status";
$lang['ClientTickets.index.heading_options'] = "Options";
$lang['ClientTickets.index.option_close'] = "Close";

$lang['ClientTickets.add.text_add_attachment'] = "Add Attachment";

$lang['ClientTickets.index.no_results'] = "There are currently no tickets with this status.";

$lang['ClientTickets.index.confirm_close'] = "Are you sure you want to close this ticket?";


// Departments
$lang['ClientTickets.departments.boxtitle_departments'] = "Support Departments";

$lang['ClientTickets.departments.heading_details'] = "Select a Department";


// Open Ticket
$lang['ClientTickets.add.boxtitle_add'] = "Open Ticket";

$lang['ClientTickets.add.heading_details'] = "Ticket Details";

$lang['ClientTickets.add.field_email'] = "Email";
$lang['ClientTickets.add.field_summary'] = "Summary";
$lang['ClientTickets.add.field_priority'] = "Priority";
$lang['ClientTickets.add.field_details'] = "Details";
$lang['ClientTickets.add.field_attachments'] = "Attachments";
$lang['ClientTickets.add.field_addsubmit'] = "Open Ticket";


// Reply to Ticket
$lang['ClientTickets.reply.boxtitle_reply'] = "Ticket #%1\$s"; // %1$s is the ticket number

$lang['ClientTickets.reply.heading_summary'] = "Summary";

$lang['ClientTickets.reply.heading_department'] = "Department";
$lang['ClientTickets.reply.heading_priority'] = "Priority";
$lang['ClientTickets.reply.heading_status'] = "Status";
$lang['ClientTickets.reply.heading_date_added'] = "Date Opened";

$lang['ClientTickets.reply.heading_reply'] = "Add Reply";
$lang['ClientTickets.reply.field_details'] = "Details";
$lang['ClientTickets.reply.field_attachments'] = "Attachments";
$lang['ClientTickets.reply.field_replysubmit'] = "Update Ticket";

$lang['ClientTickets.reply.text_add_attachment'] = "Add Attachment";

$lang['ClientTickets.reply.reply_date'] = "On %1\$s %2\$s %3\$s replied"; // %1$s is the ticket reply date, %2$s is the first name of the reply author, %3$s is the last name of the reply author
$lang['ClientTickets.reply.log_date'] = "%1\$s by %2\$s %3\$s"; // %1$s is the ticket reply date, %2$s is the first name of the reply author, %3$s is the last name of the reply author
$lang['ClientTickets.reply.system'] = "System";
$lang['ClientTickets.reply.staff_title'] = "Support Staff";
?>

==> blesta-3.4.0-3.4.4.zip: blesta/plugins/support_manager/language/en_us/client_tickets.php <==
<?php
// Success Messages
$lang['ClientTickets.!success.ticket_created'] = "The ticket #%1\$s has been successfully created."; // %1$s is the ticket number
$lang['ClientTickets.!success.ticket_updated'] = "The ticket #%1\$s has been successfully updated."; // %1$s is the ticket number
$lang['ClientTickets.!success.ticket_closed'] = "The ticket #%1\$s has been successfully closed."; // %1$s is the ticket number


// Notice messages
$lang['ClientTickets.!notice.no_departments'] = "There are no support departments available.";


// Page Titles
$lang['ClientTickets.index.page_title'] = "Support > Tickets";
$lang['ClientTickets.add.page_title'] = "Support > Open Ticket";
$lang['ClientTickets.reply.page_title'] = "Support > Update Ticket";


// Index
$lang['ClientTickets.index.category_open'] = "Open";
$lang['ClientTickets.index.category_closed'] = "Closed";

$lang['ClientTickets.index.categorylink_createticket'] = "Open Ticket";

$lang['ClientTickets.index.boxtitle_tickets'] = "Tickets";

$lang['ClientTickets.index.heading_code'] = "Ticket Number";
$lang['ClientTickets.index.heading_priority'] = "Priority";
$lang['ClientTickets.index.heading_department_name'] = "Department";
$lang['ClientTickets.index.heading_summary'] = "Summary";
$lang['ClientTickets.index.heading_last_reply_date'] = "Last Reply";
$lang['ClientTickets.index.heading_status'] = "Status";
$lang['ClientTickets.index.heading_options'] = "Options";
$lang['ClientTickets.index.option_close'] = "Close";
$lang['ClientTickets.index.option_reply'] = "Reply";

$lang['ClientTickets.add.text_add_attachment'] = "Add Attachment";

$lang['ClientTickets.index.no_results'] = "There are currently no tickets with this status.";

$lang['ClientTickets.index.confirm_close'] = "Are you sure you want to close this ticket?";


// Departments
$lang['ClientTickets.departments.boxtitle_departments'] = "Support Departments";


// Open Ticket
$lang['ClientTickets.add.boxtitle_add'] = "Open Ticket";

$lang['ClientTickets.add.field_email'] = "Email";
$lang['ClientTickets.add.field_summary'] = "Summary";
$lang['ClientTickets.add.field_priority'] = "Priority";
$lang['ClientTickets.add.field_details'] = "Details";
$lang['ClientTickets.add.field_attachments'] = "Attachments";
$lang['ClientTickets.add.field_addsubmit'] = "Open Ticket";

$lang['ClientTickets.add.placeholder_summary'] = "Enter Summary";
$lang['ClientTickets.add.placeholder_details'] = "Enter Details";


// Reply to Ticket
$lang['ClientTickets.reply.boxtitle_reply'] = "Ticket #%1\$s"; // %1$s is the ticket number

$lang['ClientTickets.reply.heading_summary'] = "Summary";

$lang['ClientTickets.reply.heading_department'] = "Department";
$lang['ClientTickets.reply.heading_priority'] = "Priority";
$lang['ClientTickets.reply.heading_status'] = "Status";
$lang['ClientTickets.reply.heading_date_added'] = "Date Opened";

$lang['ClientTickets.reply.heading_reply'] = "Add Reply";
$lang['ClientTickets.reply.placeholder_reply'] = "Enter Details";
$lang['ClientTickets.reply.field_details'] = "Details";
$lang['ClientTickets.reply.field_attachments'] = "Attachments";
$lang['ClientTickets.reply.field_replysubmit'] = "Reply";
$lang['ClientTickets.reply.field_closesubmit'] = "Close";
$lang['ClientTickets.reply.confirm_close'] = "Are you sure you want to close this ticket?";

$lang['ClientTickets.reply.text_add_attachment'] = "Add Attachment";

$lang['ClientTickets.reply.reply_date'] = "On %1\$s %2\$s %3\$s replied"; // %1$s is the ticket reply date, %2$s is the first name of the reply author, %3$s is the last name of the reply author
$lang['ClientTickets.reply.log_date'] = "%1\$s by %2\$s %3\$s"; // %1$s is the ticket reply date, %2$s is the first name of the reply author, %3$s is the last name of the reply author
$lang['ClientTickets.reply.system'] = "System";
$lang['ClientTickets.reply.staff_title'] = "Support Staff";
?>
